.. _all-salt.proxy:

=============
proxy modules
=============

.. currentmodule:: salt.proxy

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    arista_pyeapi
    chronos
    cimc
    cisconso
    deltaproxy
    docker
    dummy
    esxcluster
    esxdatacenter
    esxi
    esxvm
    fx2
    junos
    marathon
    napalm
    netmiko_px
    nxos
    nxos_api
    panos
    philips_hue
    rest_sample
    restconf
    ssh_sample
    vcenter
